@@ -1,5 +1,5 @@
-#  tests for terminado-0.9.2-py38haa244fe_0 (this is a generated file);
-print('===== testing package: terminado-0.9.2-py38haa244fe_0 =====');
+#  tests for terminado-0.9.3-py38haa244fe_0 (this is a generated file);
+print('===== testing package: terminado-0.9.3-py38haa244fe_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 """ run terminado tests with pytest, including platform- and python-based skips
@@ -13,13 +13,14 @@ import pkgutil
 import subprocess
 
 platform = sys.platform
+target_platform = os.environ["target_platform"]
 py_major = sys.version_info[:2]
 
 loader = pkgutil.get_loader("terminado.tests")
 test_path = os.path.dirname(loader.path)
 pytest = [sys.executable, "-m", "pytest"]
-cov_args = ["--cov", "terminado"]
-pytest_args = ["-o", "junit_family=xunit2", "-vv", *cov_args, test_path]
+cov_args = ["--cov", "terminado", "--no-cov-on-fail"]
+pytest_args = ["-vv", *cov_args, test_path]
 
 skips = []
 
@@ -30,6 +31,10 @@ if platform != "linux":
 if platform == "darwin":
     skips += ["unique_processes"]
 
+if "aarch64" in target_platform:
+    skips += ["max_terminals"]
+
+
 if not skips:
     print("all tests will be run", flush=True)
 
@@ -38,14 +43,14 @@ elif len(skips) == 1:
 else:
     pytest_args += ["-k", "not ({})".format(" or ".join(skips))]
 
-print("Final pytest args for", platform, py_major)
+print("Final pytest args for", platform, target_platform, py_major)
 print(" ".join([*pytest, *pytest_args]), flush=True)
 
 # actually run the tests
 sys.exit(subprocess.call([*pytest, *pytest_args]))
 #  --- run_test.py (end) ---
 
-print('===== terminado-0.9.2-py38haa244fe_0 OK =====');
+print('===== terminado-0.9.3-py38haa244fe_0 OK =====');
 print("import: 'terminado'")
 import terminado
 
